summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorTim Smith <tsmith84@gmail.com>2022-01-12 09:10:39 -0800
committerTim Smith <tsmith84@gmail.com>2022-01-12 09:10:39 -0800
commit6d88dc0f81a504c09b18452423a3646ade77a440 (patch)
treeee8b7e66dceb9b8c570c67843b064a295b68716c
parentf064c4c71e835df9dd874aa84db8735afaede8d5 (diff)
downloadchef-6d88dc0f81a504c09b18452423a3646ade77a440.tar.gz
Fix ruby cleanup breaking builds
new jmespath gem uses the VERSION file. Signed-off-by: Tim Smith <tsmith@chef.io>
-rw-r--r--omnibus/config/software/more-ruby-cleanup.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/omnibus/config/software/more-ruby-cleanup.rb b/omnibus/config/software/more-ruby-cleanup.rb
index ab399b8671..ba3c0d3fd4 100644
--- a/omnibus/config/software/more-ruby-cleanup.rb
+++ b/omnibus/config/software/more-ruby-cleanup.rb
@@ -82,8 +82,8 @@ build do
block "Removing VERSION files from installed gems" do
# find the embedded ruby gems dir and clean it up for globbing
Dir.glob("#{install_dir}/embedded/lib/ruby/gems/*/gems/*/VERSION".tr("\\", "/")).each do |f|
- # we need to not delete the aws SDK VERSION file
- next if File.basename(File.expand_path("..", f)).start_with?("aws")
+ # we need to not delete the aws SDK VERSION file or jmespath's VERSION file
+ next if File.basename(File.expand_path("..", f)).start_with?("aws", "jmespath")
puts "Deleting #{f}"
FileUtils.rm_rf(f)